@@ -66,6 +66,7 @@ from .pixelfunc import (
 
 from .sphtfunc import (
     anafast,
+    map2alm_lsq,
     map2alm,
     alm2map,
     Alm,
@@ -83,6 +84,7 @@ from .sphtfunc import (
     check_max_nside,
     map2alm_spin,
     alm2map_spin,
+    blm_gauss
 )
 
 from ._query_disc import query_disc, query_strip, query_polygon, boundaries
