@@ -77,7 +77,7 @@ def anafast(
     boundary effects.
 
     For recommendations about how to set `lmax`, `iter`, and weights, see the
-    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`
+    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`_
 
     Parameters
     ----------
@@ -106,6 +106,7 @@ def anafast(
       If there is only one input map, it has no effect. Default: True.
     datapath : None or str, optional
       If given, the directory where to find the weights data.
+      See the docstring of `map2alm` for details on how to set it up
     gal_cut : float [degrees]
       pixels at latitude in [-gal_cut;+gal_cut] are not taken into account
     use_pixel_weights: bool, optional
@@ -178,7 +179,7 @@ def map2alm(
     in ring ordering.
 
     For recommendations about how to set `lmax`, `iter`, and weights, see the
-    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`
+    `Anafast documentation <https://healpix.sourceforge.io/html/fac_anafast.htm>`_
 
     Pixel values are weighted before applying the transform:
 
@@ -191,11 +192,15 @@ def map2alm(
     Pixel weights provide the most accurate transform, so you should always use them if
     possible. However they are not included in healpy and will be automatically downloaded
     and cached in ~/.astropy the first time you compute a trasform at a specific nside.
+
     If datapath is specified, healpy will first check that local folder before downloading
     the weights.
     The easiest way to setup the folder is to clone the healpy-data repository:
+
     git clone --depth 1 https://github.com/healpy/healpy-data
-    and add the NSIDE 8192 weight from https://github.com/healpy/healpy-data/releases
+    cd healpy-data
+    bash download_weights_8192.sh
+
     and set datapath to the root of the repository.
 
     Parameters
@@ -217,7 +222,8 @@ def map2alm(
     use_weights: bool, scalar, optional
       If True, use the ring weighting. Default: False.
     datapath : None or str, optional
-      If given, the directory where to find the weights data.
+      If given, the directory where to find the pixel weights.
+      See in the docstring above details on how to set it up.
     gal_cut : float [degrees]
       pixels at latitude in [-gal_cut;+gal_cut] are not taken into account
     use_pixel_weights: bool, optional
@@ -293,6 +299,121 @@ def map2alm(
     return np.array(alms)
 
 
+def map2alm_lsq(maps, lmax, mmax, pol=True, tol=1e-10, maxiter=20):
+    """Runs an iterative map analysis up to (lmax, mmax) and returns the result
+    including its quality.
+
+    Healpix map analysis is often interpreted as "compute the `alm` for which
+    `alm2map(alm) == map`". Unfortunately this inversion problem is not solvable
+    in many cases, since `alm` typically has fewer elements than `map`, which
+    makes the equation system overdetermined, so that a solution only exists
+    for a vanishingly small subset of all possible maps. (Even if there were
+    more `alm` elements than map pixels it can happen that the problem is
+    unsolvable, but this situation should not be relevant for practical use.)
+
+    This function aims to compute instead the `alm` for which the L2 norm of
+    `alm2map(alm) - map` is minimal, i.e. it tries to find the best possible
+    least-squares approximation. Since this is an iterative procedure, the user
+    needs to specify a tolerance at which the iteration is stopped and a maximum
+    iteration count to avoid excessive run times in extreme cases.
+
+    Compared to `map2alm` this algorithm has the following advantages and
+    disadvantages:
+     - the exact number of iterations need not be specified beforehand, it will
+       stop automatically once the desired accuracy is reached.
+     - during calculation it requires more memory than `map2alm`.
+
+    Parameters
+    ----------
+    maps : array-like, shape (Npix,) or (n, Npix)
+      The input map or a list of n input maps. Must be in ring ordering.
+    lmax, mmax : int
+        The desired lmax and mmax parameters for the analysis
+    pol : bool, optional
+      If True, assumes input maps are TQU. Output will be TEB alm's.
+      (input must be 1 or 3 maps)
+      If False, apply spin 0 harmonic transform to each map.
+      (input can be any number of maps)
+      If there is only one input map, it has no effect. Default: True.
+    tol : float
+        The desired accuracy for the result. Once this is reached, the iteration
+        stops.
+    maxiter : int
+        maximum iteration count after which the minimization is stopped
+
+    Returns
+    -------
+    alm : numpy.ndarray(complex)
+        The reconstructed a_lm coefficients
+    rel_res : float
+        The norm of the residual map (i.e. `map-alm2map(alm)`), divided by the
+        norm of `maps`. This is a measure for the fraction of the map signal that
+        could not be modeled by the a_lm
+    n_iter : int
+        the number of iterations required
+    """
+    from scipy.sparse.linalg import LinearOperator, lsqr, lsmr
+    from scipy.linalg import norm
+    from .pixelfunc import npix2nside
+
+    maps = ma_to_array(maps)
+    info = maptype(maps)
+    ncomp = 1 if info == 0 else info
+    maps = np.array(maps)
+    npix = maps.size / ncomp
+    nside = pixelfunc.get_nside(maps)
+    check_max_nside(nside)
+
+    # helper functions to convert between real- and complex-valued a_lm
+    def alm2realalm(alm):
+        alm = alm.reshape((ncomp, -1))
+        res = np.zeros((ncomp, alm.shape[1] * 2 - lmax - 1))
+        for i in range(ncomp):
+            res[i, 0 : lmax + 1] = alm[i, 0 : lmax + 1].real
+            res[i, lmax + 1 :] = alm[i, lmax + 1 :].view(np.float64) * np.sqrt(2.0)
+        return res.reshape((-1,))
+
+    def realalm2alm(alm):
+        alm = np.array(alm).reshape((ncomp, -1))
+        res = np.zeros((ncomp, (alm.shape[1] + lmax + 1) // 2), dtype=np.complex128)
+        for i in range(ncomp):
+            res[i, 0 : lmax + 1] = alm[i, 0 : lmax + 1]
+            res[i, lmax + 1 :] = alm[i, lmax + 1 :].view(np.complex128) * (
+                np.sqrt(2.0) / 2
+            )
+        if ncomp == 1:
+            res = res[0]
+        return res
+
+    def a2m2(x):
+        talm = realalm2alm(x)
+        res = alm2map(talm, lmax=lmax, nside=nside, pol=pol)
+        return res.reshape((-1,))
+
+    def m2a2(x):
+        talm = map2alm(x.reshape((ncomp, -1)), lmax=lmax, iter=0, pol=pol)
+        talm *= (12 * nside ** 2) / (4 * np.pi)
+        res = alm2realalm(talm)
+        return res
+
+    # initial guess
+    alm0 = m2a2(maps) / npix * (4 * np.pi)
+    op = LinearOperator(
+        matvec=a2m2, rmatvec=m2a2, shape=(len(maps) * maps[0].size, alm0.size)
+    )
+    res = lsqr(
+        A=op,
+        b=maps.reshape((-1,)),
+        x0=alm0,
+        atol=tol,
+        btol=tol,
+        iter_lim=maxiter,
+        show=False,
+    )
+    #    res = lsmr(A=op, b=maps, x0=alm0, atol=tol, btol=tol, maxiter=maxiter, show=False)
+    return realalm2alm(res[0]), res[3] / norm(maps.reshape((-1,))), res[2]
+
+
 @deprecated_renamed_argument("verbose", None, "1.15.0")
 def alm2map(
     alms,
@@ -358,9 +479,7 @@ def alm2map(
 
     check_max_nside(nside)
 
-    alms = smoothalm(
-        alms, fwhm=fwhm, sigma=sigma, pol=pol, inplace=inplace
-    )
+    alms = smoothalm(alms, fwhm=fwhm, sigma=sigma, pol=pol, inplace=inplace)
 
     if not cb.is_seq_of_seq(alms):
         alms = [alms]
@@ -438,7 +557,7 @@ def synalm(cls, lmax=None, mmax=None, new=False, verbose=True):
     if not cb.is_seq_of_seq(cls, True):
         # Only one spectrum
         if lmax is None or lmax < 0:
-            lmax = cls.size - 1
+            lmax = len(cls) - 1
         if mmax is None or mmax < 0:
             mmax = lmax
         cls_list = [np.asarray(cls, dtype=np.float64)]
@@ -817,8 +936,11 @@ def smoothalm(
         log.info("Sigma is %f arcmin (%f rad) ", sigma * 60 * 180 / np.pi, sigma)
         log.info(
             "-> fwhm is %f arcmin",
-            sigma * 60 * 180 / np.pi * (2.0 * np.sqrt(2.0 * np.log(2.0)))
+            sigma * 60 * 180 / np.pi * (2.0 * np.sqrt(2.0 * np.log(2.0))),
         )
+    else:
+        if not isinstance(beam_window, (np.ndarray, list)):
+            raise ValueError("beam_window must be an array or list")
 
     # Check alms
     if not cb.is_seq(alms):
@@ -923,7 +1045,8 @@ def smoothing(
       If True, use pixel by pixel weighting, healpy will automatically download the weights, if needed
       See the map2alm docs for details about weighting
     datapath : None or str, optional
-      If given, the directory where to find the weights data.
+      If given, the directory where to find the pixel weights data.
+      See the docstring of `map2alm` for details on how to set it up
     verbose : bool, optional
       Deprecated, has not effect.
     nest : bool, optional
@@ -977,14 +1100,7 @@ def smoothing(
             mmax=mmax,
             inplace=True,
         )
-        output_map = alm2map(
-            alms,
-            nside,
-            lmax=lmax,
-            mmax=mmax,
-            pixwin=False,
-            pol=pol,
-        )
+        output_map = alm2map(alms, nside, lmax=lmax, mmax=mmax, pixwin=False, pol=pol)
     else:
         # Treat each map independently (any number)
         output_map = []
@@ -1000,11 +1116,7 @@ def smoothing(
                 datapath=datapath,
             )
             smoothalm(
-                alm,
-                fwhm=fwhm,
-                sigma=sigma,
-                beam_window=beam_window,
-                inplace=True,
+                alm, fwhm=fwhm, sigma=sigma, beam_window=beam_window, inplace=True
             )
             output_map.append(alm2map(alm, nside, pixwin=False))
         output_map = np.array(output_map)
@@ -1270,3 +1382,53 @@ def check_max_nside(nside):
         )
 
     return 0
+
+
+def blm_gauss(fwhm, lmax, pol=False):
+    """Computes spherical harmonic coefficients of a circular Gaussian beam
+    pointing towards the North Pole
+
+    See an example of usage
+    `in the documentation <https://healpy.readthedocs.io/en/latest/blm_gauss_plot.html>`_
+
+    Parameters
+    ----------
+    fwhm : float, scalar
+        desired FWHM of the beam, in radians
+    lmax : int, scalar
+        maximum l multipole moment to compute
+    pol : bool, scalar
+        if True, E and B coefficients will also be computed
+
+    Returns
+    -------
+    blm : array with dtype numpy.complex128
+          lmax will be as specified
+          mmax is 0 for pol==False, else 2
+    """
+    fwhm = float(fwhm)
+    lmax = int(lmax)
+    pol = bool(pol)
+    mmax = 2 if pol else 0
+    ncomp = 3 if pol else 1
+    nval = Alm.getsize(lmax, mmax)
+
+    if mmax > lmax:
+        raise ValueError("lmax value too small")
+
+    blm = np.zeros((ncomp, nval), dtype=np.complex128)
+    sigmasq = fwhm * fwhm / (8 * np.log(2.0))
+
+    for l in range(0, lmax + 1):
+        blm[0, Alm.getidx(lmax, l, 0)] = np.sqrt((2 * l + 1) / (4.0 * np.pi)) * np.exp(
+            -0.5 * sigmasq * l * l
+        )
+
+    if pol:
+        for l in range(2, lmax + 1):
+            blm[1, Alm.getidx(lmax, l, 2)] = np.sqrt(
+                (2 * l + 1) / (32 * np.pi)
+            ) * np.exp(-0.5 * sigmasq * l * l)
+        blm[2] = 1j * blm[1]
+
+    return blm
