@@ -220,6 +220,30 @@ class TestSphtFunc(unittest.TestCase):
                 output = hp.alm2map(alm, nside)
                 np.testing.assert_allclose(input, output, atol=1e-4)
 
+    def test_map2alm_lsq(self):
+        nside = 32
+        lmax = 64
+        fwhm_deg = 7.0
+        seed = 12345
+        np.random.seed(seed)
+        orig = hp.synfast(
+            self.cla,
+            nside,
+            lmax=lmax,
+            pixwin=False,
+            fwhm=np.radians(fwhm_deg),
+            new=False,
+        )
+        tmp = np.empty(orig.size * 2)
+        tmp[::2] = orig
+        maps = [orig, orig.astype(np.float32), tmp[::2]]
+        for input in maps:
+            alm, l2, it = hp.map2alm_lsq(input, tol=1e-4, lmax=lmax, mmax=lmax)
+            np.testing.assert_equal(l2 < 1e-3, True)
+            np.testing.assert_equal(it < 15, True)
+            output = hp.alm2map(alm, nside)
+            np.testing.assert_allclose(input, output, atol=1e-4)
+
     def test_map2alm_pol(self):
         tmp = [np.empty(o.size * 2) for o in self.mapiqu]
         for t, o in zip(tmp, self.mapiqu):
@@ -236,6 +260,25 @@ class TestSphtFunc(unittest.TestCase):
                 for i, o in zip(input, output):
                     np.testing.assert_allclose(i, o, atol=1e-4)
 
+    def test_map2alm_lsq_pol(self):
+        tmp = [np.empty(o.size * 2) for o in self.mapiqu]
+        for t, o in zip(tmp, self.mapiqu):
+            t[::2] = o
+        maps = [
+            self.mapiqu,
+            [o.astype(np.float32) for o in self.mapiqu],
+            [t[::2] for t in tmp],
+        ]
+        for input in maps:
+            alm, l2, it = hp.map2alm_lsq(
+                input, tol=1e-4, lmax=self.lmax, mmax=self.lmax
+            )
+            np.testing.assert_equal(l2 < 1e-3, True)
+            np.testing.assert_equal(it < 15, True)
+            output = hp.alm2map(alm, 32)
+            for i, o in zip(input, output):
+                np.testing.assert_allclose(i, o, atol=1e-4)
+
     def test_map2alm_pol_gal_cut(self):
         tmp = [np.empty(o.size * 2) for o in self.mapiqu]
         for t, o in zip(tmp, self.mapiqu):
@@ -360,8 +403,8 @@ class TestSphtFunc(unittest.TestCase):
         np.testing.assert_allclose(ref, mine, rtol=1e-10)
 
     def test_accept_ma_allows_only_keywords(self):
-        """ Test whether 'smoothing' wrapped with accept_ma works with only
-            keyword arguments. """
+        """Test whether 'smoothing' wrapped with accept_ma works with only
+        keyword arguments."""
 
         ma = np.ones(12 * 16 ** 2)
         try:
@@ -370,7 +413,7 @@ class TestSphtFunc(unittest.TestCase):
             self.fail()
 
     def test_beam2bl(self):
-        """ Test beam2bl against analytical transform of Gaussian beam. """
+        """Test beam2bl against analytical transform of Gaussian beam."""
 
         theta = np.linspace(0, np.radians(1.0), 1000)
         sigma = np.radians(10.0 / 60.0) / np.sqrt(8.0 * np.log(2.0))
@@ -383,7 +426,7 @@ class TestSphtFunc(unittest.TestCase):
         np.testing.assert_allclose(gaussian_window, bl, rtol=1e-4)
 
     def test_bl2beam(self):
-        """ Test bl2beam against analytical transform of Gaussian beam. """
+        """Test bl2beam against analytical transform of Gaussian beam."""
 
         theta = np.linspace(0, np.radians(3.0), 1000)
         sigma = np.radians(1.0) / np.sqrt(8.0 * np.log(2.0))
@@ -396,7 +439,7 @@ class TestSphtFunc(unittest.TestCase):
         np.testing.assert_allclose(gaussian_beam, beam, rtol=1e-3)
 
     def test_max_nside_check(self):
-        """ Test whether the max_nside_check correctly raises ValueErrors for nsides
+        """Test whether the max_nside_check correctly raises ValueErrors for nsides
         that are too large."""
 
         # Test an nside that is too large
@@ -441,5 +484,166 @@ class TestSphtFunc(unittest.TestCase):
         with pytest.raises(ValueError):
             hp.rotate_alm(alm, 0.1, 0.2, 0.3)
 
+    def test_blm_gauss(self):
+        lmax = 16
+        pol = True
+        blm = hp.blm_gauss(np.radians(30), lmax=lmax, pol=pol)
+        blm_ref = np.array(
+            [
+                [
+                    0.28209479 + 0.0j,
+                    0.47667223 + 0.0j,
+                    0.57139535 + 0.0j,
+                    0.59747744 + 0.0j,
+                    0.56982677 + 0.0j,
+                    0.50430742 + 0.0j,
+                    0.4177115 + 0.0j,
+                    0.32537519 + 0.0j,
+                    0.23907031 + 0.0j,
+                    0.16602316 + 0.0j,
+                    0.10912406 + 0.0j,
+                    0.06795511 + 0.0j,
+                    0.04012396 + 0.0j,
+                    0.02247603 + 0.0j,
+                    0.01195003 + 0.0j,
+                    0.0060327 + 0.0j,
+                    0.00289252 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                ],
+                [
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.20201876 + 0.0j,
+                    0.21124017 + 0.0j,
+                    0.20146419 + 0.0j,
+                    0.1782996 + 0.0j,
+                    0.14768332 + 0.0j,
+                    0.1150375 + 0.0j,
+                    0.08452412 + 0.0j,
+                    0.05869805 + 0.0j,
+                    0.03858118 + 0.0j,
+                    0.02402576 + 0.0j,
+                    0.01418596 + 0.0j,
+                    0.00794648 + 0.0j,
+                    0.00422497 + 0.0j,
+                    0.00213288 + 0.0j,
+                    0.00102266 + 0.0j,
+                ],
+                [
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.0j,
+                    0.0 + 0.20201876j,
+                    0.0 + 0.21124017j,
+                    0.0 + 0.20146419j,
+                    0.0 + 0.1782996j,
+                    0.0 + 0.14768332j,
+                    0.0 + 0.1150375j,
+                    0.0 + 0.08452412j,
+                    0.0 + 0.05869805j,
+                    0.0 + 0.03858118j,
+                    0.0 + 0.02402576j,
+                    0.0 + 0.01418596j,
+                    0.0 + 0.00794648j,
+                    0.0 + 0.00422497j,
+                    0.0 + 0.00213288j,
+                    0.0 + 0.00102266j,
+                ],
+            ]
+        )
+
+        np.testing.assert_allclose(blm, blm_ref, atol=1e-7)
+
 if __name__ == "__main__":
     unittest.main()
